.. _rockverse_docs_gethelp:

Getting Help
============

If you encounter issues or have questions, here are ways to get support:

- **GitHub Issues**:
  Report bugs, suggest features, or ask questions on our
  `GitHub Issues page <https://github.com/rodolfovictor/rockverse/issues>`_.

- **Stack Overflow**: Join discussions by tagging questions with ``rockverse``
  for targeted support. Visit `Stack Overflow <https://stackoverflow.com/tags/rockverse>`_.

- **LinkedIn**: Connect with me on `LinkedIn <https://br.linkedin.com/in/rodolfovictor>`_.

- **Email**: Feel free to `email me <mailto:rodolfo@rodolfovictor.com>`_
  for questions, feedback, or collaboration opportunities.

- **Subscribe**: :ref:`Join our mailing list <rockverse_docs_maillist>`
  to receive notifications about RockVerse updates.